==> mt-bean-validators-0.55.4-test-sources.jar: de/knightsoftnet/validators/shared/testcases/MustBeBiggerDateTestCases.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package de.knightsoftnet.validators.shared.testcases;

import de.knightsoftnet.validators.shared.beans.MustBeBiggerDateTestBean;

import org.apache.commons.lang3.time.DateUtils;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * get test cases for must be bigger test with date values.
 *
 * @author Manfred Tremmel
 *
 */
public class MustBeBiggerDateTestCases {
  /**
   * get empty test beans.
   *
   * @return empty test bean
   */
  public static final List<MustBeBiggerDateTestBean> getEmptyTestBeans() {
    final List<MustBeBiggerDateTestBean> correctCases = new ArrayList<>();
    correctCases.add(new MustBeBiggerDateTestBean(null, null));
    return correctCases;
  }

  /**
   * get correct test beans.
   *
   * @return correct test beans
   */
  public static final List<MustBeBiggerDateTestBean> getCorrectTestBeans() {
    final List<MustBeBiggerDateTestBean> correctCases = new ArrayList<>();
    final Date now = new Date();
    final Date future = DateUtils.addMilliseconds(now, 1);
    correctCases.add(new MustBeBiggerDateTestBean(null, now));
    correctCases.add(new MustBeBiggerDateTestBean(now, future));
    return correctCases;
  }

  /**
   * get wrong test beans.
   *
   * @return wrong test beans
   */
  public static final List<MustBeBiggerDateTestBean> getWrongTestBeans() {
    final List<MustBeBiggerDateTestBean> wrongCases = new ArrayList<>();
    final Date now = new Date();
    final Date future = DateUtils.addMilliseconds(now, 1);
    wrongCases.add(new MustBeBiggerDateTestBean(future, now));
    wrongCases.add(new MustBeBiggerDateTestBean(now, now));
    wrongCases.add(new MustBeBiggerDateTestBean(now, null));
    return wrongCases;
  }
}

==> mt-bean-validators-2.0.12-test-sources.jar: de/knightsoftnet/validators/shared/testcases/MustBeBiggerDateTestCases.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package de.knightsoftnet.validators.shared.testcases;

import de.knightsoftnet.validators.shared.beans.MustBeBiggerDateTestBean;

import org.apache.commons.lang3.time.DateUtils;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * get test cases for must be bigger test with date values.
 *
 * @author Manfred Tremmel
 *
 */
public class MustBeBiggerDateTestCases {
  /**
   * get empty test beans.
   *
   * @return empty test bean
   */
  public static final List<MustBeBiggerDateTestBean> getEmptyTestBeans() {
    final List<MustBeBiggerDateTestBean> correctCases = new ArrayList<>();
    correctCases.add(new MustBeBiggerDateTestBean(null, null));
    return correctCases;
  }

  /**
   * get correct test beans.
   *
   * @return correct test beans
   */
  public static final List<MustBeBiggerDateTestBean> getCorrectTestBeans() {
    final List<MustBeBiggerDateTestBean> correctCases = new ArrayList<>();
    final Date now = new Date();
    final Date future = DateUtils.addSeconds(now, 1);
    correctCases.add(new MustBeBiggerDateTestBean(null, now));
    correctCases.add(new MustBeBiggerDateTestBean(now, future));
    return correctCases;
  }

  /**
   * get wrong test beans.
   *
   * @return wrong test beans
   */
  public static final List<MustBeBiggerDateTestBean> getWrongTestBeans() {
    final List<MustBeBiggerDateTestBean> wrongCases = new ArrayList<>();
    final Date now = new Date();
    final Date future = DateUtils.addSeconds(now, 1);
    wrongCases.add(new MustBeBiggerDateTestBean(future, now));
    wrongCases.add(new MustBeBiggerDateTestBean(now, now));
    wrongCases.add(new MustBeBiggerDateTestBean(now, null));
    return wrongCases;
  }
}
